<?php
/**
 * Register Standard Type 3.
 *
 * @package Verta
 */

/**
 * Register New Layout
 *
 * @param array $layouts List of layouts.
 */
function csco_canvas_register_layout_standard_type_3( $layouts = array() ) {

	$layout = 'standard-type-3';

	// Add new layout.
	$layouts[ $layout ] = array(
		'location'    => array(),
		'name'        => esc_html__( 'Standard 3', 'verta' ),
		'template'    => get_template_directory() . '/template-parts/blocks/posts-area.php',
		'icon'        => '<svg height="44" viewBox="0 0 52 44" width="52" xmlns="http://www.w3.org/2000/svg"><g fill="none" fill-rule="evenodd" transform="translate(1 1)"><path d="m26.5440341 19.1818182v-8.1818182h-2.0234375l-2.5205966 1.5958807v1.9090909l2.3316761-1.4616477h.0596591v6.1384943z" fill="#2d2d2d" fill-rule="nonzero"/><g stroke="#2d2d2d"><rect height="42" rx="3" stroke-width="1.5" width="50"/><rect height="14" rx="1" stroke-width="1.5" width="18" x="16" y="8"/><path d="m21.412325 28h7" stroke-linecap="round" stroke-linejoin="round"/><path d="m17 31h16" stroke-linecap="round" stroke-linejoin="round"/><path d="m19.5 34h11" stroke-linecap="round" stroke-linejoin="round"/></g></g></svg>',
		'sections'    => array(
			'general'    => array(
				'title'    => esc_html__( 'Block Settings', 'verta' ),
				'priority' => 5,
				'open'     => true,
			),
			'post-meta'  => array(
				'title'    => esc_html__( 'Meta Settings', 'verta' ),
				'priority' => 10,
			),
			'typography' => array(
				'title'    => esc_html__( 'Typography Settings', 'verta' ),
				'priority' => 10,
			),
		),
		'hide_fields' => csco_get_gutenberg_posts_hide_fields(),
		'fields'      => array_merge(
			csco_get_gutenberg_pagination_fields(),

			array(
				array(
					'key'            => 'columns',
					'label'          => esc_html__( 'Number of Columns', 'verta' ),
					'section'        => 'general',
					'type'           => 'number',
					'min'            => 1,
					'max'            => 6,
					'default'        => 1,
					'default_tablet' => 1,
					'default_mobile' => 1,
					'responsive'     => true,
					'output'         => array(
						array(
							'element'  => '$ .cs-posts-area__main',
							'property' => '--cs-posts-area-grid-columns',
							'suffix'   => '!important',
						),
					),
				),
				array(
					'key'            => 'gap_posts',
					'label'          => esc_html__( 'Gap between Posts', 'verta' ),
					'type'           => 'dimension',
					'section'        => 'general',
					'responsive'     => true,
					'default'        => '40px',
					'default_tablet' => '40px',
					'default_mobile' => '40px',
					'output'         => array(
						array(
							'element'  => '$ .cs-posts-area__main',
							'property' => '--cs-posts-area-grid-gap',
							'suffix'   => '!important',
						),
					),
				),
				array(
					'key'             => 'bordersBetweenPosts',
					'label'           => esc_html__( 'Display borders between posts', 'verta' ),
					'section'         => 'general',
					'type'            => 'toggle',
					'default'         => false,
					'active_callback' => array(
						array(
							'field'    => '$#columns',
							'operator' => '==',
							'value'    => '1',
						),
					),
				),
				array(
					'key'     => 'post_format',
					'label'   => esc_html__( 'Display post format', 'verta' ),
					'section' => 'general',
					'type'    => 'toggle',
					'default' => true,
				),
				array(
					'key'     => 'video',
					'label'   => esc_html__( 'Enable video backgrounds', 'verta' ),
					'section' => 'general',
					'type'    => 'toggle',
					'default' => false,
				),
				array(
					'key'             => 'video_type',
					'label'           => esc_html__( 'Video Type Background', 'verta' ),
					'section'         => 'general',
					'type'            => 'toggle',
					'type'            => 'select',
					'default'         => 'always',
					'choices'         => array(
						'always' => esc_html__( 'Always', 'verta' ),
						'hover'  => esc_html__( 'On Hover', 'verta' ),
					),
					'active_callback' => array(
						array(
							'field'    => '$#video',
							'operator' => '==',
							'value'    => true,
						),
					),
				),
				array(
					'key'             => 'video_controls',
					'label'           => esc_html__( 'Enable video controls', 'verta' ),
					'section'         => 'general',
					'type'            => 'toggle',
					'default'         => false,
					'active_callback' => array(
						array(
							'field'    => '$#video',
							'operator' => '==',
							'value'    => true,
						),
					),
				),
				array(
					'key'     => 'title_underline',
					'label'   => esc_html__( 'Display heading underline', 'verta' ),
					'section' => 'general',
					'type'    => 'toggle',
					'default' => true,
				),
				array(
					'key'             => 'meta_category_type',
					'label'           => esc_html__( 'Category type', 'verta' ),
					'section'         => 'post-meta',
					'type'            => 'select',
					'default'         => '',
					'choices'         => array(
						'one'   => esc_html__( 'Type 1', 'verta' ),
						'two'   => esc_html__( 'Type 2', 'verta' ),
						'three' => esc_html__( 'Type 3', 'verta' ),
					),
					'active_callback' => array(
						array(
							'field'    => '$#showMetaCategory',
							'operator' => '==',
							'value'    => true,
						),
					),
				),
				// Thumbnail.
				array(
					'key'     => 'featured_image',
					'label'   => esc_html__( 'Display Featured Image', 'verta' ),
					'section' => 'thumbnail',
					'type'    => 'toggle',
					'default' => true,
				),
				array(
					'key'             => 'imageOrientation',
					'label'           => esc_html__( 'Image Orientation', 'verta' ),
					'section'         => 'thumbnail',
					'type'            => 'select',
					'default'         => 'original',
					'choices'         => array(
						'original'       => esc_html__( 'Original', 'verta' ),
						'landscape-16-9' => esc_html__( 'Landscape 16:9', 'verta' ),
						'landscape-3-2'  => esc_html__( 'Landscape 3:2', 'verta' ),
						'landscape'      => esc_html__( 'Landscape 4:3', 'verta' ),
						'square'         => esc_html__( 'Square', 'verta' ),
						'portrait'       => esc_html__( 'Portrait', 'verta' ),
						'portrait-2-3'   => esc_html__( 'Portrait 2:3', 'verta' ),
					),
					'active_callback' => array(
						array(
							'field'    => '$#featured_image',
							'operator' => '===',
							'value'    => true,
						),
					),
				),
				array(
					'key'             => 'imageSize',
					'label'           => esc_html__( 'Images Size', 'verta' ),
					'section'         => 'thumbnail',
					'type'            => 'select',
					'default'         => 'medium_large',
					'choices'         => csco_get_list_available_image_sizes(),
					'active_callback' => array(
						array(
							'field'    => '$#featured_image',
							'operator' => '===',
							'value'    => true,
						),
					),
				),
				array(
					'key'             => 'imageBorderRadius',
					'label'           => esc_html__( 'Image Border Radius', 'verta' ),
					'section'         => 'thumbnail',
					'type'            => 'dimension',
					'output'          => array(
						array(
							'element'  => '$',
							'property' => '--cs-thumbnail-border-radius',
						),
					),
					'active_callback' => array(
						array(
							'field'    => '$#featured_image',
							'operator' => '===',
							'value'    => true,
						),
					),
				),
				// Typography.
				array(
					'key'        => 'typographyHeading',
					'label'      => esc_html__( 'Heading Font Size', 'verta' ),
					'section'    => 'typography',
					'type'       => 'dimension',
					'default'    => '1.125rem',
					'responsive' => true,
					'output'     => array(
						array(
							'element'  => '$ .cs-entry__title',
							'property' => 'font-size',
							'suffix'   => '!important',
						),
					),
				),
				array(
					'key'     => 'typographyHeadingTag',
					'label'   => esc_html__( 'Heading Tag', 'verta' ),
					'section' => 'typography',
					'type'    => 'select',
					'default' => 'h2',
					'choices' => array(
						'h1'  => esc_html__( 'H1', 'verta' ),
						'h2'  => esc_html__( 'H2', 'verta' ),
						'h3'  => esc_html__( 'H3', 'verta' ),
						'h4'  => esc_html__( 'H4', 'verta' ),
						'h5'  => esc_html__( 'H5', 'verta' ),
						'h6'  => esc_html__( 'H6', 'verta' ),
						'p'   => esc_html__( 'P', 'verta' ),
						'div' => esc_html__( 'DIV', 'verta' ),
					),
				),
				array(
					'key'             => 'typographyExcerpt',
					'label'           => esc_html__( 'Excerpt Font Size', 'verta' ),
					'section'         => 'typography',
					'type'            => 'dimension',
					'default'         => '1rem',
					'responsive'      => true,
					'output'          => array(
						array(
							'element'  => '$ .cs-entry__excerpt',
							'property' => '--cs-font-entry-excerpt-size',
							'suffix'   => '!important',
						),
					),
					'active_callback' => array(
						array(
							'field'    => '$#showExcerpt',
							'operator' => '===',
							'value'    => true,
						),
					),
				),
				array(
					'key'             => 'typography_counter',
					'label'           => esc_html__( 'Counter Font Size', 'verta' ),
					'section'         => 'typography',
					'type'            => 'dimension',
					'default'         => '2.5rem',
					'responsive'      => true,
					'output'          => array(
						array(
							'element'  => '$',
							'property' => '--cs-font-numbered-post-size',
							'suffix'   => '!important',
						),
					),
					'active_callback' => array(
						array(
							'field'    => '$#show_counter',
							'operator' => '===',
							'value'    => true,
						),
						array(
							'field'    => '$#featured_image',
							'operator' => '===',
							'value'    => true,
						),
					),
				),
				// Color Settings.
				array(
					'key'     => 'colorBasicHeading',
					'label'   => esc_html__( 'Heading', 'verta' ),
					'section' => 'color',
					'type'    => 'color',
					'output'  => array(
						array(
							'element'  => '$ .cs-entry__title a',
							'property' => 'color',
							'suffix'   => '!important',
						),
					),
				),
				array(
					'key'     => 'colorBasicHeadingHover',
					'label'   => esc_html__( 'Heading Hover', 'verta' ),
					'section' => 'color',
					'type'    => 'color',
					'output'  => array(
						array(
							'element'  => '$ .cs-entry__title a:hover, $ .cs-entry__title a:focus',
							'property' => 'color',
							'suffix'   => '!important',
						),
					),
				),
				array(
					'key'             => 'heading_underline_color',
					'label'           => esc_html__( 'Heading Underline Color', 'verta' ),
					'section'         => 'color',
					'type'            => 'color',
					'output'          => array(
						array(
							'element'  => '$ .cs-posts-area__title-underline .cs-entry__title:before',
							'property' => '--cs-color-accent',
							'suffix'   => '!important',
						),
					),
					'active_callback' => array(
						array(
							'field'    => '$#title_underline',
							'operator' => '===',
							'value'    => true,
						),
					),
				),
				array(
					'key'             => 'colorBasicExcerpt',
					'label'           => esc_html__( 'Excerpt', 'verta' ),
					'section'         => 'color',
					'type'            => 'color',
					'output'          => array(
						array(
							'element'  => '$ .cs-entry__excerpt',
							'property' => 'color',
							'suffix'   => '!important',
						),
					),
					'active_callback' => array(
						array(
							'field'    => '$#showExcerpt',
							'operator' => '===',
							'value'    => true,
						),
					),
				),
				array(
					'key'     => 'colorBasicMeta',
					'label'   => esc_html__( 'Post Meta', 'verta' ),
					'section' => 'color',
					'type'    => 'color',
					'output'  => array(
						array(
							'element'  => '$ .cs-entry__post-meta',
							'property' => 'color',
							'suffix'   => '!important',
						),
					),
				),
				array(
					'key'     => 'colorBasicMetaLinks',
					'label'   => esc_html__( 'Post Meta Links', 'verta' ),
					'section' => 'color',
					'type'    => 'color',
					'output'  => array(
						array(
							'element'  => '$ .cs-entry__post-meta div:not(.cs-meta-category) a',
							'property' => 'color',
							'suffix'   => '!important',
						),
					),
				),
				array(
					'key'     => 'colorBasicMetaLinksHover',
					'label'   => esc_html__( 'Post Meta Links Hover', 'verta' ),
					'section' => 'color',
					'type'    => 'color',
					'output'  => array(
						array(
							'element'  => '$ .cs-entry__post-meta div:not(.cs-meta-category) a:hover, $ .cs-entry__post-meta div:not(.cs-meta-category) a:focus',
							'property' => 'color',
							'suffix'   => '!important',
						),
					),
				),
				array(
					'key'             => 'colorBasicCategory',
					'label'           => esc_html__( 'Category Color', 'verta' ),
					'section'         => 'color',
					'type'            => 'color',
					'output'          => array(
						array(
							'element'  => '$ .cs-entry__post-meta .cs-meta-category, $ .cs-entry__post-meta .cs-meta-category a',
							'property' => '--cs-color-category',
							'suffix'   => '!important',
						),
					),
					'active_callback' => array(
						array(
							'field'    => '$#meta_category_type',
							'operator' => '!=',
							'value'    => 'two',
						),
						array(
							'field'    => '$#showMetaCategory',
							'operator' => '==',
							'value'    => true,
						),
					),
				),
				array(
					'key'             => 'colorBasicCategoryHover',
					'label'           => esc_html__( 'Category Hover Color', 'verta' ),
					'section'         => 'color',
					'type'            => 'color',
					'output'          => array(
						array(
							'element'  => '$ .cs-entry__post-meta .cs-meta-category a:hover',
							'property' => '--cs-color-category-hover',
							'suffix'   => '!important',
						),
					),
					'active_callback' => array(
						array(
							'field'    => '$#meta_category_type',
							'operator' => '!=',
							'value'    => 'two',
						),
						array(
							'field'    => '$#showMetaCategory',
							'operator' => '==',
							'value'    => true,
						),
					),
				),
				array(
					'key'             => 'colorBasicCategories',
					'label'           => esc_html__( 'Styled Category Color', 'verta' ),
					'section'         => 'color',
					'type'            => 'color',
					'output'          => array(
						array(
							'element'  => '$ .cs-meta-category, $ .cs-meta-category a',
							'property' => '--cs-color-styled-category-contrast',
							'suffix'   => '!important',
						),
					),
					'active_callback' => array(
						array(
							'field'    => '$#meta_category_type',
							'operator' => '==',
							'value'    => 'two',
						),
						array(
							'field'    => '$#showMetaCategory',
							'operator' => '==',
							'value'    => true,
						),
					),
				),
				array(
					'key'             => 'colorBasicCategoriesHover',
					'label'           => esc_html__( 'Styled Category Hover Color', 'verta' ),
					'section'         => 'color',
					'type'            => 'color',
					'output'          => array(
						array(
							'element'  => '$ .cs-meta-category:hover, $ .cs-meta-category a:hover',
							'property' => '--cs-color-styled-category-hover-contrast',
							'suffix'   => '!important',
						),
					),
					'active_callback' => array(
						array(
							'field'    => '$#meta_category_type',
							'operator' => '==',
							'value'    => 'two',
						),
						array(
							'field'    => '$#showMetaCategory',
							'operator' => '==',
							'value'    => true,
						),
					),
				),
				array(
					'key'             => 'colorBasicCategoriesBG',
					'label'           => esc_html__( 'Styled Category Background', 'verta' ),
					'section'         => 'color',
					'type'            => 'color',
					'output'          => array(
						array(
							'element'  => '$ .cs-meta-category a',
							'property' => '--cs-color-styled-category',
							'suffix'   => '!important',
						),
					),
					'active_callback' => array(
						array(
							'field'    => '$#meta_category_type',
							'operator' => '==',
							'value'    => 'two',
						),
						array(
							'field'    => '$#showMetaCategory',
							'operator' => '==',
							'value'    => true,
						),
					),
				),
				array(
					'key'             => 'colorBasicCategoriesBGHover',
					'label'           => esc_html__( 'Styled Category Background Hover', 'verta' ),
					'section'         => 'color',
					'type'            => 'color',
					'output'          => array(
						array(
							'element'  => '$ .cs-meta-category a:hover',
							'property' => '--cs-color-styled-category-hover',
							'suffix'   => '!important',
						),
						array(
							'element'  => '$ .cs-meta-category a:hover',
							'property' => '--cs-color-styled-category',
							'suffix'   => '!important',
						),
					),
					'active_callback' => array(
						array(
							'field'    => '$#meta_category_type',
							'operator' => '==',
							'value'    => 'two',
						),
						array(
							'field'    => '$#showMetaCategory',
							'operator' => '==',
							'value'    => true,
						),
					),
				),
				array(
					'key'             => 'colorBasicCategoryUnderline',
					'label'           => esc_html__( 'Category Underline Color', 'verta' ),
					'section'         => 'color',
					'type'            => 'color',
					'output'          => array(
						array(
							'element'  => '$ .cs-meta-category',
							'property' => '--cs-color-category-underline',
							'suffix'   => '!important',
						),
					),
					'active_callback' => array(
						array(
							'field'    => '$#meta_category_type',
							'operator' => '==',
							'value'    => 'three',
						),
						array(
							'field'    => '$#showMetaCategory',
							'operator' => '==',
							'value'    => true,
						),
					),
				),
				array(
					'key'             => 'morebutton_background',
					'label'           => esc_html__( 'More Button Background Color', 'verta' ),
					'section'         => 'color',
					'type'            => 'color',
					'output'          => array(
						array(
							'element'  => '$ .cs-entry__read-more a',
							'property' => '--cs-color-button',
							'suffix'   => '!important',
						),
					),
					'active_callback' => array(
						array(
							'field'    => '$#moreButton',
							'operator' => '==',
							'value'    => true,
						),
					),
				),
				array(
					'key'             => 'morebutton_background_hover',
					'label'           => esc_html__( 'More Button Background Hover Color', 'verta' ),
					'section'         => 'color',
					'type'            => 'color',
					'output'          => array(
						array(
							'element'  => '$ .cs-entry__read-more a:hover',
							'property' => '--cs-color-button-hover',
							'suffix'   => '!important',
						),
					),
					'active_callback' => array(
						array(
							'field'    => '$#moreButton',
							'operator' => '==',
							'value'    => true,
						),
					),
				),
			),
			// Primary Meta.
			csco_get_gutenberg_meta_fields(
				array(
					'section_name' => 'post-meta',
					'default'      => array(
						'category'     => true,
						'author'       => true,
						'date'         => true,
						'comments'     => false,
						'views'        => true,
						'reading_time' => false,
						'shares'       => true,
						'photos'       => false,
						'duration'     => false,
					),
				)
			),
			csco_get_gutenberg_excerpt_fields(
				array(
					'section_name' => 'post-meta',
					'default'      => true,
				)
			),
			csco_get_gutenberg_more_button_fields(
				array(
					'section_name' => 'post-meta',
				)
			)
		),
	);

	return $layouts;
}
add_filter( 'canvas_block_layouts_canvas/posts', 'csco_canvas_register_layout_standard_type_3' );
