<?php
/**
 * Register Tile Type 1.
 *
 * @package Verta
 */

/**
 * Register New Layout
 *
 * @param array $layouts List of layouts.
 */
function csco_canvas_register_layout_tile_type_1( $layouts = array() ) {

	$layout = 'tile-type-1';

	// Add new layout.
	$layouts[ $layout ] = array(
		'location'    => array(),
		'name'        => esc_html__( 'Tile 1', 'verta' ),
		'template'    => get_template_directory() . '/template-parts/blocks/posts-area.php',
		'icon'        => '<svg height="44" viewBox="0 0 52 44" width="52" xmlns="http://www.w3.org/2000/svg"><g fill="none" fill-rule="evenodd"><rect height="42" rx="3" stroke="#2d2d2d" stroke-width="1.5" width="50" x="1" y="1"/><path d="m5.5 25h25v10h-25z" fill="#2d2d2d"/><g stroke-linecap="round" stroke-linejoin="round"><path d="m9 28.5h17" stroke="#fff"/><path d="m9 31.5h13" stroke="#fff"/><path d="m6.5 38h5" stroke="#2d2d2d"/></g></g></svg>',
		'sections'    => array(
			'general'    => array(
				'title'    => esc_html__( 'Block Settings', 'verta' ),
				'priority' => 5,
				'open'     => true,
			),
			'post-meta'  => array(
				'title'    => esc_html__( 'Meta Settings', 'verta' ),
				'priority' => 10,
			),
			'typography' => array(
				'title'    => esc_html__( 'Typography Settings', 'verta' ),
				'priority' => 10,
			),
		),
		'hide_fields' => csco_get_gutenberg_posts_hide_fields(),
		'fields'      => array_merge(
			csco_get_gutenberg_pagination_fields(),

			array(
				array(
					'key'            => 'columns',
					'label'          => esc_html__( 'Number of Columns', 'verta' ),
					'section'        => 'general',
					'type'           => 'number',
					'min'            => 1,
					'max'            => 6,
					'default'        => 1,
					'default_tablet' => 1,
					'default_mobile' => 1,
					'responsive'     => true,
					'output'         => array(
						array(
							'element'  => '$ .cs-posts-area__main',
							'property' => '--cs-posts-area-grid-columns',
							'suffix'   => '!important',
						),
					),
				),
				array(
					'key'            => 'gap_posts',
					'label'          => esc_html__( 'Gap between Posts', 'verta' ),
					'type'           => 'dimension',
					'section'        => 'general',
					'responsive'     => true,
					'default'        => '40px',
					'default_tablet' => '40px',
					'default_mobile' => '40px',
					'output'         => array(
						array(
							'element'  => '$ .cs-posts-area__main',
							'property' => '--cs-posts-area-grid-gap',
							'suffix'   => '!important',
						),
					),
				),
				array(
					'key'        => 'height',
					'label'      => esc_html__( 'Min Height', 'verta' ),
					'type'       => 'dimension',
					'default'    => 'initial',
					'section'    => 'general',
					'responsive' => true,
					'output'     => array(
						array(
							'element'  => '$ .cs-entry__outer',
							'property' => 'min-height',
							'suffix'   => '!important',
						),
					),
				),
				array(
					'key'     => 'bordersBetweenPosts',
					'label'   => esc_html__( 'Display borders between posts', 'verta' ),
					'section' => 'general',
					'type'    => 'toggle',
					'default' => false,
				),
				array(
					'key'     => 'video',
					'label'   => esc_html__( 'Enable video backgrounds', 'verta' ),
					'section' => 'general',
					'type'    => 'toggle',
					'default' => false,
				),
				array(
					'key'             => 'video_type',
					'label'           => esc_html__( 'Video Type Background', 'verta' ),
					'section'         => 'general',
					'type'            => 'toggle',
					'type'            => 'select',
					'default'         => 'always',
					'choices'         => array(
						'always' => esc_html__( 'Always', 'verta' ),
						'hover'  => esc_html__( 'On Hover', 'verta' ),
					),
					'active_callback' => array(
						array(
							'field'    => '$#video',
							'operator' => '==',
							'value'    => true,
						),
					),
				),
				array(
					'key'             => 'video_controls',
					'label'           => esc_html__( 'Enable video controls', 'verta' ),
					'section'         => 'general',
					'type'            => 'toggle',
					'default'         => false,
					'active_callback' => array(
						array(
							'field'    => '$#video',
							'operator' => '==',
							'value'    => true,
						),
					),
				),
				// Thumbnail.
				array(
					'key'     => 'imageOrientation',
					'label'   => esc_html__( 'Image Orientation', 'verta' ),
					'section' => 'thumbnail',
					'type'    => 'select',
					'default' => 'stretch',
					'choices' => array(
						'stretch'   => esc_html__( 'Stretch', 'verta' ),
						'landscape' => esc_html__( 'Landscape', 'verta' ),
						'portrait'  => esc_html__( 'Portrait', 'verta' ),
						'square'    => esc_html__( 'Square', 'verta' ),
					),
				),
				array(
					'key'     => 'imageSize',
					'label'   => esc_html__( 'Images Size', 'verta' ),
					'section' => 'thumbnail',
					'type'    => 'select',
					'default' => 'medium_large',
					'choices' => csco_get_list_available_image_sizes(),
				),
				array(
					'key'     => 'imageBorderRadius',
					'label'   => esc_html__( 'Image Border Radius', 'verta' ),
					'section' => 'thumbnail',
					'type'    => 'dimension',
					'output'  => array(
						array(
							'element'  => '$ .cs-entry__outer',
							'property' => '--cs-thumbnail-border-radius',
						),
					),
				),
				// Typography.
				array(
					'key'        => 'typographyHeading',
					'label'      => esc_html__( 'Heading Font Size', 'verta' ),
					'section'    => 'typography',
					'type'       => 'dimension',
					'default'    => '1.125rem',
					'responsive' => true,
					'output'     => array(
						array(
							'element'  => '$ .cs-entry__title',
							'property' => 'font-size',
							'suffix'   => '!important',
						),
					),
				),
				array(
					'key'     => 'typographyHeadingTag',
					'label'   => esc_html__( 'Heading Tag', 'verta' ),
					'section' => 'typography',
					'type'    => 'select',
					'default' => 'h2',
					'choices' => array(
						'h1'  => esc_html__( 'H1', 'verta' ),
						'h2'  => esc_html__( 'H2', 'verta' ),
						'h3'  => esc_html__( 'H3', 'verta' ),
						'h4'  => esc_html__( 'H4', 'verta' ),
						'h5'  => esc_html__( 'H5', 'verta' ),
						'h6'  => esc_html__( 'H6', 'verta' ),
						'p'   => esc_html__( 'P', 'verta' ),
						'div' => esc_html__( 'DIV', 'verta' ),
					),
				),
				array(
					'key'             => 'typographyExcerpt',
					'label'           => esc_html__( 'Excerpt Font Size', 'verta' ),
					'section'         => 'typography',
					'type'            => 'dimension',
					'default'         => '1rem',
					'responsive'      => true,
					'output'          => array(
						array(
							'element'  => '$ .cs-entry__excerpt',
							'property' => 'font-size',
							'suffix'   => '!important',
						),
					),
					'active_callback' => array(
						array(
							'field'    => '$#showExcerpt',
							'operator' => '===',
							'value'    => true,
						),
					),
				),
				array(
					'key'             => 'colorBasicCategories',
					'label'           => esc_html__( 'Styled Category Color', 'verta' ),
					'section'         => 'color',
					'type'            => 'color',
					'output'          => array(
						array(
							'element'  => '$ .cs-entry__category a',
							'property' => '--cs-color-post-meta-link',
							'suffix'   => '!important',
						),
					),
					'active_callback' => array(
						array(
							'field'    => '$#showMetaCategory',
							'operator' => '==',
							'value'    => true,
						),
					),
				),
				array(
					'key'             => 'colorBasicCategoriesHover',
					'label'           => esc_html__( 'Styled Category Hover Color', 'verta' ),
					'section'         => 'color',
					'type'            => 'color',
					'output'          => array(
						array(
							'element'  => '$ .cs-entry__category a:hover',
							'property' => '--cs-color-post-meta-link-hover',
							'suffix'   => '!important',
						),
					),
					'active_callback' => array(
						array(
							'field'    => '$#showMetaCategory',
							'operator' => '==',
							'value'    => true,
						),
					),
				),
				array(
					'key'             => 'colorBasicCategoriesBG',
					'label'           => esc_html__( 'Styled Category Background', 'verta' ),
					'section'         => 'color',
					'type'            => 'color',
					'output'          => array(
						array(
							'element'  => '$ .cs-entry__category a',
							'property' => '--cs-color-accent',
							'suffix'   => '!important',
						),
					),
					'active_callback' => array(
						array(
							'field'    => '$#showMetaCategory',
							'operator' => '==',
							'value'    => true,
						),
					),
				),
				array(
					'key'             => 'colorBasicCategoriesBGHover',
					'label'           => esc_html__( 'Styled Category Background Hover', 'verta' ),
					'section'         => 'color',
					'type'            => 'color',
					'output'          => array(
						array(
							'element'  => '$ .cs-entry__category a:hover',
							'property' => '--cs-color-accent-contrast',
							'suffix'   => '!important',
						),
					),
					'active_callback' => array(
						array(
							'field'    => '$#showMetaCategory',
							'operator' => '==',
							'value'    => true,
						),
					),
				),
			),
			// Primary Meta.
			csco_get_gutenberg_meta_fields(
				array(
					'section_name' => 'post-meta',
				)
			),
			csco_get_gutenberg_excerpt_fields(
				array(
					'section_name' => 'post-meta',
					'default'      => true,
				)
			)
		),
	);

	return $layouts;
}
add_filter( 'canvas_block_layouts_canvas/posts', 'csco_canvas_register_layout_tile_type_1' );
