<?php
/**
 * Footer Settings
 *
 * @package Verta
 */

CSCO_Kirki::add_section(
	'footer',
	array(
		'title'    => esc_html__( 'Footer Settings', 'verta' ),
		'priority' => 40,
	)
);


CSCO_Kirki::add_field(
	'csco_theme_mod',
	array(
		'type'        => 'collapsible',
		'settings'    => 'footer_collapsible_common',
		'label'       => esc_html__( 'Common', 'verta' ),
		'section'     => 'footer',
		'priority'    => 10,
		'input_attrs' => array(
			'collapsed' => true,
		),
	)
);

CSCO_Kirki::add_field(
	'csco_theme_mod',
	array(
		'type'     => 'radio',
		'settings' => 'footer_layout',
		'label'    => esc_html__( 'Layout', 'verta' ),
		'section'  => 'footer',
		'default'  => 'six',
		'priority' => 10,
		'choices'  => array(
			'one'   => esc_html__( 'Footer 1', 'verta' ),
			'two'   => esc_html__( 'Footer 2', 'verta' ),
			'three' => esc_html__( 'Footer 3', 'verta' ),
			'four'  => esc_html__( 'Footer 4', 'verta' ),
			'five'  => esc_html__( 'Footer 5', 'verta' ),
			'six'   => esc_html__( 'Footer 6', 'verta' ),
			'seven' => esc_html__( 'Footer 7', 'verta' ),
		),
	)
);

CSCO_Kirki::add_field(
	'csco_theme_mod',
	array(
		'type'              => 'textarea',
		'settings'          => 'footer_copyright',
		'label'             => esc_html__( 'Footer Copyright', 'verta' ),
		'section'           => 'footer',
		/* translators: %s: Author name. */
		'default'           => sprintf( esc_html__( 'Designed & Developed by %s', 'verta' ), '<a href="' . esc_url( csco_get_theme_data( 'AuthorURI' ) ) . '">Code Supply Co.</a>' ),
		'priority'          => 10,
		'sanitize_callback' => 'wp_kses_post',
		'active_callback'   => array(
			array(
				'setting'  => 'footer_layout',
				'operator' => 'in',
				'value'    => array( 'one', 'three', 'four', 'five', 'six', 'seven' ),
			),
		),
	)
);

CSCO_Kirki::add_field(
	'csco_theme_mod',
	array(
		'type'              => 'textarea',
		'settings'          => 'footer_text',
		'label'             => esc_html__( 'Footer Text', 'verta' ),
		'section'           => 'footer',
		'default'           => '',
		'priority'          => 10,
		'sanitize_callback' => 'wp_kses_post',
		'active_callback'   => array(
			array(
				'setting'  => 'footer_layout',
				'operator' => 'in',
				'value'    => array( 'two', 'four', 'five', 'six' ),
			),
		),
	)
);

if ( csco_powerkit_module_enabled( 'opt_in_forms' ) ) {
	CSCO_Kirki::add_field(
		'csco_theme_mod',
		array(
			'type'            => 'collapsible',
			'settings'        => 'footer_collapsible_subscription',
			'label'           => esc_html__( 'Subscription Form', 'verta' ),
			'section'         => 'footer',
			'priority'        => 10,
			'active_callback' => array(
				array(
					'setting'  => 'footer_layout',
					'operator' => 'in',
					'value'    => array( 'two', 'three', 'four', 'five', 'six', 'seven' ),
				),
			),
		)
	);

	CSCO_Kirki::add_field(
		'csco_theme_mod',
		array(
			'type'            => 'checkbox',
			'settings'        => 'footer_subscribe',
			'label'           => esc_html__( 'Display subscribe section', 'verta' ),
			'section'         => 'footer',
			'default'         => false,
			'priority'        => 10,
			'active_callback' => array(
				array(
					'setting'  => 'footer_layout',
					'operator' => 'in',
					'value'    => array( 'two', 'three', 'four', 'five', 'six', 'seven' ),
				),
			),
		)
	);

	CSCO_Kirki::add_field(
		'csco_theme_mod',
		array(
			'type'            => 'checkbox',
			'settings'        => 'footer_subscribe_name',
			'label'           => esc_html__( 'Display first name field', 'verta' ),
			'section'         => 'footer',
			'default'         => false,
			'priority'        => 10,
			'active_callback' => array(
				array(
					'setting'  => 'footer_subscribe',
					'operator' => '==',
					'value'    => true,
				),
				array(
					'setting'  => 'footer_layout',
					'operator' => 'in',
					'value'    => array( 'two', 'three', 'four', 'five', 'six', 'seven' ),
				),
			),
		)
	);

	CSCO_Kirki::add_field(
		'csco_theme_mod',
		array(
			'type'              => 'text',
			'settings'          => 'footer_subscribe_heading',
			'label'             => esc_html__( 'Heading', 'verta' ),
			'section'           => 'footer',
			'default'           => '',
			'priority'          => 10,
			'sanitize_callback' => 'wp_kses_post',
			'active_callback'   => array(
				array(
					'setting'  => 'footer_subscribe',
					'operator' => '==',
					'value'    => true,
				),
				array(
					'setting'  => 'footer_layout',
					'operator' => 'in',
					'value'    => array( 'two', 'three', 'four', 'five', 'six', 'seven' ),
				),
			),
		)
	);

	CSCO_Kirki::add_field(
		'csco_theme_mod',
		array(
			'type'              => 'text',
			'settings'          => 'footer_subscribe_title',
			'label'             => esc_html__( 'Title', 'verta' ),
			'section'           => 'footer',
			'default'           => esc_html__( 'Sign Up for Our Newsletters', 'verta' ),
			'priority'          => 10,
			'sanitize_callback' => 'wp_kses_post',
			'active_callback'   => array(
				array(
					'setting'  => 'footer_subscribe',
					'operator' => '==',
					'value'    => true,
				),
				array(
					'setting'  => 'footer_layout',
					'operator' => 'in',
					'value'    => array( 'two', 'three', 'four', 'five', 'six', 'seven' ),
				),
			),
		)
	);

	CSCO_Kirki::add_field(
		'csco_theme_mod',
		array(
			'type'              => 'text',
			'settings'          => 'footer_subscribe_text',
			'label'             => esc_html__( 'Text', 'verta' ),
			'section'           => 'footer',
			'default'           => esc_html__( 'Get notified of the best deals on our WordPress themes.', 'verta' ),
			'priority'          => 10,
			'sanitize_callback' => 'wp_kses_post',
			'active_callback'   => array(
				array(
					'setting'  => 'footer_subscribe',
					'operator' => '==',
					'value'    => true,
				),
				array(
					'setting'  => 'footer_layout',
					'operator' => 'in',
					'value'    => array( 'two', 'three', 'four', 'five', 'six', 'seven' ),
				),
			),
		)
	);

	CSCO_Kirki::add_field(
		'csco_theme_mod', array(
			'type'            => 'image',
			'settings'        => 'footer_subscribe_image',
			'label'           => esc_html__( 'Image', 'verta' ),
			'section'         => 'footer',
			'default'         => '',
			'choices'         => array(
				'save_as' => 'id',
			),
			'active_callback' => array(
				array(
					'setting'  => 'footer_layout',
					'operator' => 'in',
					'value'    => array( 'seven' ),
				),
			),
		)
	);
}

if ( csco_powerkit_module_enabled( 'social_links' ) ) {
	CSCO_Kirki::add_field(
		'csco_theme_mod',
		array(
			'type'            => 'collapsible',
			'settings'        => 'footer_collapsible_social',
			'label'           => esc_html__( 'Social Links', 'verta' ),
			'section'         => 'footer',
			'priority'        => 10,
			'active_callback' => array(
				array(
					'setting'  => 'footer_layout',
					'operator' => 'in',
					'value'    => array( 'one', 'three', 'four', 'six', 'seven' ),
				),
			),
		)
	);

	CSCO_Kirki::add_field(
		'csco_theme_mod',
		array(
			'type'            => 'checkbox',
			'settings'        => 'footer_social_links',
			'label'           => esc_html__( 'Display social links', 'verta' ),
			'section'         => 'footer',
			'default'         => false,
			'priority'        => 10,
			'active_callback' => array(
				array(
					'setting'  => 'footer_layout',
					'operator' => 'in',
					'value'    => array( 'one', 'three', 'four', 'six', 'seven' ),
				),
			),
		)
	);

	CSCO_Kirki::add_field(
		'csco_theme_mod',
		array(
			'type'            => 'select',
			'settings'        => 'footer_social_links_scheme',
			'label'           => esc_html__( 'Color scheme', 'verta' ),
			'section'         => 'footer',
			'default'         => 'light',
			'priority'        => 10,
			'choices'         => array(
				'default' => esc_html__( 'Light', 'verta' ),
				'bold'    => esc_html__( 'Bold', 'verta' ),
			),
			'active_callback' => array(
				array(
					'setting'  => 'footer_social_links',
					'operator' => '==',
					'value'    => true,
				),
				array(
					'setting'  => 'footer_layout',
					'operator' => 'in',
					'value'    => array( 'one', 'three', 'four', 'six', 'seven' ),
				),
			),
		)
	);

	CSCO_Kirki::add_field(
		'csco_theme_mod',
		array(
			'type'            => 'number',
			'settings'        => 'footer_social_links_maximum',
			'label'           => esc_html__( 'Maximum Number of Social Links', 'verta' ),
			'section'         => 'footer',
			'default'         => 4,
			'priority'        => 10,
			'active_callback' => array(
				array(
					'setting'  => 'footer_social_links',
					'operator' => '==',
					'value'    => true,
				),
				array(
					'setting'  => 'footer_layout',
					'operator' => 'in',
					'value'    => array( 'one', 'three', 'four', 'six', 'seven' ),
				),
			),
		)
	);

	CSCO_Kirki::add_field(
		'csco_theme_mod',
		array(
			'type'            => 'checkbox',
			'settings'        => 'footer_social_links_counts',
			'label'           => esc_html__( 'Display counts', 'verta' ),
			'section'         => 'footer',
			'default'         => true,
			'priority'        => 10,
			'active_callback' => array(
				array(
					'setting'  => 'footer_social_links',
					'operator' => '==',
					'value'    => true,
				),
				array(
					'setting'  => 'footer_layout',
					'operator' => 'in',
					'value'    => array( 'one', 'three', 'four', 'six', 'seven' ),
				),
			),
		)
	);
}

CSCO_Kirki::add_field(
	'csco_theme_mod',
	array(
		'type'            => 'collapsible',
		'settings'        => 'footer_collapsible_posts',
		'label'           => esc_html__( 'Posts', 'verta' ),
		'section'         => 'footer',
		'priority'        => 10,
		'active_callback' => array(
			array(
				'setting'  => 'footer_layout',
				'operator' => '==',
				'value'    => 'four',
			),
		),
	)
);

CSCO_Kirki::add_field(
	'csco_theme_mod',
	array(
		'type'            => 'text',
		'settings'        => 'footer_posts_heading',
		'label'           => esc_html__( 'Heading', 'verta' ),
		'section'         => 'footer',
		'default'         => esc_html__( 'Latest Posts', 'verta' ),
		'priority'        => 10,
		'active_callback' => array(
			array(
				'setting'  => 'footer_layout',
				'operator' => '==',
				'value'    => 'four',
			),
		),
	)
);

CSCO_Kirki::add_field(
	'csco_theme_mod',
	array(
		'type'            => 'slider',
		'settings'        => 'footer_post_count',
		'label'           => esc_html__( 'Posts Count', 'verta' ),
		'section'         => 'footer',
		'default'         => 2,
		'choices'         => array(
			'min'  => 1,
			'max'  => 4,
			'step' => 1,
		),
		'priority'        => 10,
		'active_callback' => array(
			array(
				'setting'  => 'footer_layout',
				'operator' => '==',
				'value'    => 'four',
			),
		),
	)
);

CSCO_Kirki::add_field(
	'csco_theme_mod',
	array(
		'type'            => 'select',
		'settings'        => 'footer_image_orientation',
		'label'           => esc_html__( 'Image Orientation', 'verta' ),
		'section'         => 'footer',
		'default'         => 'square',
		'choices'         => array(
			'original'  => esc_html__( 'Original', 'verta' ),
			'landscape' => esc_html__( 'Landscape', 'verta' ),
			'portrait'  => esc_html__( 'Portrait', 'verta' ),
			'square'    => esc_html__( 'Square', 'verta' ),
		),
		'priority'        => 10,
		'active_callback' => array(
			array(
				'setting'  => 'footer_layout',
				'operator' => '==',
				'value'    => 'four',
			),
		),
	)
);

CSCO_Kirki::add_field(
	'csco_theme_mod',
	array(
		'type'     => 'checkbox',
		'settings' => 'footer_post_has_thumbnail',
		'label'    => esc_html__( 'Display only posts with featured image', 'verta' ),
		'section'  => 'footer',
		'default'  => false,
		'priority' => 10,
	)
);

CSCO_Kirki::add_field(
	'csco_theme_mod',
	array(
		'type'            => 'multicheck',
		'settings'        => 'footer_post_meta',
		'label'           => esc_html__( 'Post Meta', 'verta' ),
		'section'         => 'footer',
		'default'         => array( 'category' ),
		'priority'        => 10,
		'choices'         => apply_filters(
			'csco_post_meta_choices',
			array(
				'category' => esc_html__( 'Category', 'verta' ),
				'date'     => esc_html__( 'Date', 'verta' ),
			)
		),
		'active_callback' => array(
			array(
				'setting'  => 'footer_layout',
				'operator' => '==',
				'value'    => 'four',
			),
		),
	)
);

do_action( 'csco_theme_mods_footer_after' );
