<?php
/**
 * Post Settings
 *
 * @package Verta
 */

CSCO_Kirki::add_section(
	'post_settings',
	array(
		'title'    => esc_html__( 'Post Settings', 'verta' ),
		'priority' => 50,
	)
);

CSCO_Kirki::add_field(
	'csco_theme_mod',
	array(
		'type'        => 'collapsible',
		'settings'    => 'post_collapsible_common',
		'section'     => 'post_settings',
		'label'       => esc_html__( 'Common', 'verta' ),
		'priority'    => 10,
		'input_attrs' => array(
			'collapsed' => true,
		),
	)
);

CSCO_Kirki::add_field(
	'csco_theme_mod',
	array(
		'type'     => 'radio',
		'settings' => 'post_sidebar',
		'label'    => esc_html__( 'Default Sidebar', 'verta' ),
		'section'  => 'post_settings',
		'default'  => 'right',
		'priority' => 10,
		'choices'  => array(
			'right'    => esc_html__( 'Right Sidebar', 'verta' ),
			'left'     => esc_html__( 'Left Sidebar', 'verta' ),
			'disabled' => esc_html__( 'No Sidebar', 'verta' ),
		),
	)
);

CSCO_Kirki::add_field(
	'csco_theme_mod',
	array(
		'type'     => 'multicheck',
		'settings' => 'post_meta',
		'label'    => esc_html__( 'Post Meta', 'verta' ),
		'section'  => 'post_settings',
		'default'  => array( 'category', 'author', 'views', 'shares', 'reading_time' ),
		'priority' => 10,
		'choices'  => apply_filters(
			'csco_post_meta_choices',
			array(
				'category'     => esc_html__( 'Category', 'verta' ),
				'date'         => esc_html__( 'Date', 'verta' ),
				'author'       => esc_html__( 'Author', 'verta' ),
				'views'        => esc_html__( 'Views', 'verta' ),
				'shares'       => esc_html__( 'Shares', 'verta' ),
				'comments'     => esc_html__( 'Comments', 'verta' ),
				'reading_time' => esc_html__( 'Reading Time', 'verta' ),
				'photos'       => esc_html__( 'Photos', 'verta' ),
				'duration'     => esc_html__( 'Duration', 'verta' ),
			)
		),
	)
);

CSCO_Kirki::add_field(
	'csco_theme_mod',
	array(
		'type'     => 'radio',
		'settings' => 'post_header_type',
		'label'    => esc_html__( 'Default Post Header Type', 'verta' ),
		'section'  => 'post_settings',
		'default'  => 'standard',
		'priority' => 10,
		'choices'  => array(
			'standard'          => esc_html__( 'Standard', 'verta' ),
			'compact'           => esc_html__( 'Compact', 'verta' ),
			'compact-alt'       => esc_html__( 'Compact Alt', 'verta' ),
			'compact-boxed'     => esc_html__( 'Compact Boxed', 'verta' ),
			'compact-alt-boxed' => esc_html__( 'Compact Alt Boxed', 'verta' ),
			'large'             => esc_html__( 'Large', 'verta' ),
			'title'             => esc_html__( 'Page Title Only', 'verta' ),
			'none'              => esc_html__( 'None', 'verta' ),
		),
	)
);

CSCO_Kirki::add_field(
	'csco_theme_mod',
	array(
		'type'            => 'radio',
		'settings'        => 'post_media_preview',
		'label'           => esc_html__( 'Standard Page Header Preview', 'verta' ),
		'section'         => 'post_settings',
		'default'         => 'cropped',
		'priority'        => 10,
		'choices'         => array(
			'cropped'   => esc_html__( 'Display Cropped Image', 'verta' ),
			'uncropped' => esc_html__( 'Display Preview in Original Ratio', 'verta' ),
		),
		'active_callback' => array(
			array(
				'setting'  => 'post_header_type',
				'operator' => '==',
				'value'    => 'standard',
			),
		),
	)
);

CSCO_Kirki::add_field(
	'csco_theme_mod',
	array(
		'type'     => 'checkbox',
		'settings' => 'post_subtitle',
		'label'    => esc_html__( 'Display excerpt as post subtitle', 'verta' ),
		'section'  => 'post_settings',
		'default'  => true,
		'priority' => 10,
	)
);

CSCO_Kirki::add_field(
	'csco_theme_mod',
	array(
		'type'     => 'checkbox',
		'settings' => 'post_author',
		'label'    => esc_html__( 'Display post author', 'verta' ),
		'section'  => 'post_settings',
		'default'  => false,
		'priority' => 10,
	)
);

CSCO_Kirki::add_field(
	'csco_theme_mod',
	array(
		'type'     => 'checkbox',
		'settings' => 'post_tags',
		'label'    => esc_html__( 'Display tags', 'verta' ),
		'section'  => 'post_settings',
		'default'  => true,
		'priority' => 10,
	)
);

CSCO_Kirki::add_field(
	'csco_theme_mod',
	array(
		'type'     => 'checkbox',
		'settings' => 'post_comments_simple',
		'label'    => esc_html__( 'Display comments without the View Comments button', 'verta' ),
		'section'  => 'post_settings',
		'default'  => false,
		'priority' => 10,
	)
);

if ( csco_powerkit_module_enabled( 'opt_in_forms' ) ) {
	CSCO_Kirki::add_field(
		'csco_theme_mod',
		array(
			'type'     => 'collapsible',
			'settings' => 'post_collapsible_subscription_form',
			'section'  => 'post_settings',
			'label'    => esc_html__( 'Subscription Form', 'verta' ),
			'priority' => 10,
		)
	);

	CSCO_Kirki::add_field(
		'csco_theme_mod',
		array(
			'type'     => 'checkbox',
			'settings' => 'post_subscribe',
			'label'    => esc_html__( 'Display subscribe section', 'verta' ),
			'section'  => 'post_settings',
			'default'  => true,
			'priority' => 10,
		)
	);

	CSCO_Kirki::add_field(
		'csco_theme_mod',
		array(
			'type'            => 'checkbox',
			'settings'        => 'post_subscribe_name',
			'label'           => esc_html__( 'Display first name field', 'verta' ),
			'section'         => 'post_settings',
			'default'         => true,
			'priority'        => 10,
			'active_callback' => array(
				array(
					'setting'  => 'post_subscribe',
					'operator' => '==',
					'value'    => true,
				),
			),
		)
	);

	CSCO_Kirki::add_field(
		'csco_theme_mod',
		array(
			'type'            => 'text',
			'settings'        => 'post_subscribe_title',
			'label'           => esc_html__( 'Title', 'verta' ),
			'section'         => 'post_settings',
			'default'         => esc_html__( 'Sign Up for Our Newsletters', 'verta' ),
			'priority'        => 10,
			'active_callback' => array(
				array(
					'setting'  => 'post_subscribe',
					'operator' => '==',
					'value'    => true,
				),
			),
		)
	);

	CSCO_Kirki::add_field(
		'csco_theme_mod',
		array(
			'type'              => 'text',
			'settings'          => 'post_subscribe_text',
			'label'             => esc_html__( 'Text', 'verta' ),
			'section'           => 'post_settings',
			'default'           => esc_html__( 'Get notified of the best deals on our WordPress themes.', 'verta' ),
			'priority'          => 10,
			'sanitize_callback' => 'wp_kses_post',
			'active_callback'   => array(
				array(
					'setting'  => 'post_subscribe',
					'operator' => '==',
					'value'    => true,
				),
			),
		)
	);
}

CSCO_Kirki::add_field(
	'csco_theme_mod',
	array(
		'type'     => 'collapsible',
		'settings' => 'post_collapsible_prev_next',
		'section'  => 'post_settings',
		'label'    => esc_html__( 'Prev Next Links', 'verta' ),
		'priority' => 10,
	)
);

CSCO_Kirki::add_field(
	'csco_theme_mod',
	array(
		'type'     => 'checkbox',
		'settings' => 'post_prev_next',
		'label'    => esc_html__( 'Display prev next links', 'verta' ),
		'section'  => 'post_settings',
		'default'  => true,
		'priority' => 10,
	)
);

CSCO_Kirki::add_field(
	'csco_theme_mod',
	array(
		'type'            => 'select',
		'settings'        => 'post_prev_next_image_orientation',
		'label'           => esc_html__( 'Image Orientation', 'verta' ),
		'section'         => 'post_settings',
		'default'         => 'square',
		'choices'         => array(
			'original'  => esc_html__( 'Original', 'verta' ),
			'landscape' => esc_html__( 'Landscape', 'verta' ),
			'portrait'  => esc_html__( 'Portrait', 'verta' ),
			'square'    => esc_html__( 'Square', 'verta' ),
		),
		'priority'        => 10,
		'active_callback' => array(
			array(
				'setting'  => 'post_prev_next',
				'operator' => '==',
				'value'    => true,
			),
		),
	)
);

CSCO_Kirki::add_field(
	'csco_theme_mod',
	array(
		'type'            => 'select',
		'settings'        => 'post_prev_next_image_size',
		'label'           => esc_html__( 'Image Size', 'verta' ),
		'section'         => 'post_settings',
		'default'         => 'csco-small',
		'choices'         => csco_get_list_available_image_sizes(),
		'priority'        => 10,
		'active_callback' => array(
			array(
				'setting'  => 'post_prev_next',
				'operator' => '==',
				'value'    => true,
			),
		),
	)
);

CSCO_Kirki::add_field(
	'csco_theme_mod',
	array(
		'type'            => 'dimension',
		'settings'        => 'post_prev_next_image_border_radius',
		'label'           => esc_html__( 'Image Border Radius', 'verta' ),
		'section'         => 'post_settings',
		'default'         => '30px',
		'priority'        => 10,
		'output'          => array(
			array(
				'element'  => '.cs-entry__prev-next',
				'property' => '--cs-thumbnail-border-radius',
				'suffix'   => '!important',
			),
		),
		'active_callback' => array(
			array(
				'setting'  => 'post_prev_next',
				'operator' => '==',
				'value'    => true,
			),
		),
	)
);

CSCO_Kirki::add_field(
	'csco_theme_mod',
	array(
		'type'            => 'multicheck',
		'settings'        => 'post_prev_next_meta',
		'label'           => esc_html__( 'Post Meta', 'verta' ),
		'section'         => 'post_settings',
		'default'         => array( 'date' ),
		'priority'        => 10,
		'choices'         => apply_filters(
			'csco_post_meta_choices',
			array(
				'category'     => esc_html__( 'Category', 'verta' ),
				'date'         => esc_html__( 'Date', 'verta' ),
				'author'       => esc_html__( 'Author', 'verta' ),
				'views'        => esc_html__( 'Views', 'verta' ),
				'shares'       => esc_html__( 'Shares', 'verta' ),
				'comments'     => esc_html__( 'Comments', 'verta' ),
				'reading_time' => esc_html__( 'Reading Time', 'verta' ),
			)
		),
		'active_callback' => array(
			array(
				'setting'  => 'post_prev_next',
				'operator' => '==',
				'value'    => true,
			),
		),
	)
);

CSCO_Kirki::add_field(
	'csco_theme_mod',
	array(
		'type'     => 'collapsible',
		'settings' => 'post_collapsible_related_posts',
		'section'  => 'post_settings',
		'label'    => esc_html__( 'Related Posts', 'verta' ),
		'priority' => 10,
	)
);

CSCO_Kirki::add_field(
	'csco_theme_mod',
	array(
		'type'     => 'checkbox',
		'settings' => 'related',
		'label'    => esc_html__( 'Display related section', 'verta' ),
		'section'  => 'post_settings',
		'default'  => true,
		'priority' => 10,
	)
);

CSCO_Kirki::add_field(
	'csco_theme_mod',
	array(
		'type'            => 'select',
		'settings'        => 'related_image_orientation',
		'label'           => esc_html__( 'Image Orientation', 'verta' ),
		'section'         => 'post_settings',
		'default'         => 'original',
		'choices'         => array(
			'original'  => esc_html__( 'Original', 'verta' ),
			'landscape' => esc_html__( 'Landscape', 'verta' ),
			'portrait'  => esc_html__( 'Portrait 3:4', 'verta' ),
			'square'    => esc_html__( 'Square', 'verta' ),
		),
		'priority'        => 10,
		'active_callback' => array(
			array(
				'setting'  => 'related',
				'operator' => '==',
				'value'    => true,
			),
		),
	)
);

CSCO_Kirki::add_field(
	'csco_theme_mod',
	array(
		'type'            => 'select',
		'settings'        => 'related_image_size',
		'label'           => esc_html__( 'Image Size', 'verta' ),
		'section'         => 'post_settings',
		'default'         => 'csco-thumbnail-small',
		'choices'         => csco_get_list_available_image_sizes(),
		'priority'        => 10,
		'active_callback' => array(
			array(
				'setting'  => 'related',
				'operator' => '==',
				'value'    => true,
			),
		),
	)
);

CSCO_Kirki::add_field(
	'csco_theme_mod',
	array(
		'type'            => 'multicheck',
		'settings'        => 'related_post_meta',
		'label'           => esc_html__( 'Post Meta', 'verta' ),
		'section'         => 'post_settings',
		'default'         => array( 'category', 'author' ),
		'priority'        => 10,
		'choices'         => apply_filters(
			'csco_post_meta_choices',
			array(
				'category'     => esc_html__( 'Category', 'verta' ),
				'date'         => esc_html__( 'Date', 'verta' ),
				'author'       => esc_html__( 'Author', 'verta' ),
				'views'        => esc_html__( 'Views', 'verta' ),
				'shares'       => esc_html__( 'Shares', 'verta' ),
				'comments'     => esc_html__( 'Comments', 'verta' ),
				'reading_time' => esc_html__( 'Reading Time', 'verta' ),
			)
		),
		'active_callback' => array(
			array(
				'setting'  => 'related',
				'operator' => '==',
				'value'    => true,
			),
		),
	)
);

CSCO_Kirki::add_field(
	'csco_theme_mod',
	array(
		'type'            => 'number',
		'settings'        => 'related_number',
		'label'           => esc_html__( 'Maximum Number of Related Posts', 'verta' ),
		'section'         => 'post_settings',
		'default'         => 4,
		'priority'        => 10,
		'active_callback' => array(
			array(
				'setting'  => 'related',
				'operator' => '==',
				'value'    => true,
			),
		),
	)
);

if ( csco_post_views_enabled() ) {

	CSCO_Kirki::add_field(
		'csco_theme_mod',
		array(
			'type'            => 'radio',
			'settings'        => 'related_orderby',
			'label'           => esc_html__( 'Order posts by', 'verta' ),
			'section'         => 'post_settings',
			'default'         => 'rand',
			'priority'        => 10,
			'choices'         => array(
				'rand'       => esc_html__( 'Rand', 'verta' ),
				'date'       => esc_html__( 'Date', 'verta' ),
				'post_views' => esc_html__( 'Views', 'verta' ),
			),
			'active_callback' => array(
				array(
					'setting'  => 'related',
					'operator' => '==',
					'value'    => true,
				),
			),
		)
	);

	CSCO_Kirki::add_field(
		'csco_theme_mod',
		array(
			'type'            => 'text',
			'settings'        => 'related_time_frame',
			'label'           => esc_html__( 'Time Frame', 'verta' ),
			'description'     => esc_html__( 'Add period of posts in English. For example: &laquo;2 months&raquo;, &laquo;14 days&raquo; or even &laquo;1 year&raquo;', 'verta' ),
			'section'         => 'post_settings',
			'default'         => '',
			'priority'        => 10,
			'active_callback' => array(
				array(
					'setting'  => 'related',
					'operator' => '==',
					'value'    => true,
				),
				array(
					'setting'  => 'related_orderby',
					'operator' => '==',
					'value'    => 'post_views',
				),
			),
		)
	);
}

CSCO_Kirki::add_field(
	'csco_theme_mod',
	array(
		'type'     => 'collapsible',
		'settings' => 'post_collapsible_load_nextpost',
		'section'  => 'post_settings',
		'label'    => esc_html__( 'Auto Load Next Post', 'verta' ),
		'priority' => 10,
	)
);

CSCO_Kirki::add_field(
	'csco_theme_mod',
	array(
		'type'     => 'checkbox',
		'settings' => 'post_load_nextpost',
		'label'    => esc_html__( 'Enable the Auto Load Next Post feature', 'verta' ),
		'section'  => 'post_settings',
		'default'  => false,
		'priority' => 10,
	)
);

CSCO_Kirki::add_field(
	'csco_theme_mod',
	array(
		'type'            => 'checkbox',
		'settings'        => 'post_load_nextpost_same_category',
		'label'           => esc_html__( 'Auto load posts from the same category only', 'verta' ),
		'section'         => 'post_settings',
		'default'         => false,
		'priority'        => 10,
		'active_callback' => array(
			array(
				'setting'  => 'post_load_nextpost',
				'operator' => '==',
				'value'    => true,
			),
		),
	)
);

CSCO_Kirki::add_field(
	'csco_theme_mod',
	array(
		'type'            => 'checkbox',
		'settings'        => 'post_load_nextpost_reverse',
		'label'           => esc_html__( 'Auto load previous posts instead of next ones', 'verta' ),
		'section'         => 'post_settings',
		'default'         => false,
		'priority'        => 10,
		'active_callback' => array(
			array(
				'setting'  => 'post_load_nextpost',
				'operator' => '==',
				'value'    => true,
			),
		),
	)
);
