<?php
/**
 * Template part for displaying posts
 *
 * @link https://developer.wordpress.org/themes/basics/template-hierarchy/
 *
 * @package Verta
 */

$options = get_query_var( 'options' );

// Thumbnail size.
$thumbnail_size = $options['image_size'];

if ( 'full' === $options['layout'] ) {
	$thumbnail_size = 'csco-large';
	if ( 'uncropped' === csco_get_page_preview() ) {
		$thumbnail_size = sprintf( '%s-uncropped', $thumbnail_size );
	}
}

$summary_type = false;
if ( isset( $options['summary_type'] ) ) {
	$summary_type = $options['summary_type'];
}

$more_button = false;
if ( isset( $options['more_button'] ) ) {
	$more_button = $options['more_button'];
}
?>

<article <?php post_class(); ?>>
	<div class="cs-entry__outer">
		<?php if ( has_post_thumbnail() ) { ?>
			<div class="cs-entry__inner cs-entry__thumbnail cs-entry__overlay cs-overlay-ratio cs-ratio-<?php echo esc_attr( $options['image_orientation'] ); ?>" data-scheme="inverse">

				<div class="cs-overlay-background cs-overlay-transparent">
					<?php the_post_thumbnail( $thumbnail_size ); ?>
				</div>

				<?php csco_get_video_background( 'archive' ); ?>

				<?php csco_the_post_format_icon(); ?>

				<a href="<?php echo esc_url( get_permalink() ); ?>" class="cs-overlay-link"></a>
			</div>
		<?php } ?>

		<div class="cs-entry__inner cs-entry__content">

			<?php csco_get_post_meta( array( 'category', 'date', 'photos' ), false, true, $options['meta'] ); ?>

			<?php the_title( '<h2 class="cs-entry__title"><a href="' . esc_url( get_permalink() ) . '">', '</a></h2>' ); ?>

			<?php if ( 'full' === $options['layout'] ) { ?>
				<div class="cs-entry__excerpt cs-entry-type-<?php echo esc_attr( $summary_type ); ?> ">
					<?php
					if ( 'summary' === $summary_type ) {
						the_excerpt();
					} else {
						$more_link_text = false;

						if ( $more_button ) {
							$more_link_text = sprintf(
								/* translators: %s: Name of current post */
								__( 'Continue reading<span class="screen-reader-text"> "%s"</span>', 'verta' ),
								get_the_title()
							);
						}

						the_content( $more_link_text );
					}
					?>
				</div>
			<?php } else { ?>
				<?php
				$post_excerpt = get_the_excerpt();
				if ( false !== $summary_type ) {
					if ( $post_excerpt ) {
						?>
						<div class="cs-entry__excerpt">
							<?php echo wp_kses_post( $post_excerpt ); ?>
						</div>
						<?php
					}
				}
				?>
			<?php } ?>

			<?php
			if ( 'summary' === $summary_type && $more_button ) {
				?>
					<div class="cs-entry__read-more">
						<a class="cs-button" href="<?php echo esc_url( get_permalink() ); ?>">
							<?php echo esc_html( apply_filters( 'csco_filter_label_more', null ) ); ?>
						</a>
					</div>
				<?php
			}
			?>

			<?php csco_get_post_meta( array( 'author', 'views', 'shares', 'comments', 'reading_time', 'duration' ), false, true, $options['meta'] ); ?>
		</div>
	</div>
</article>
